﻿using System;
using System.Collections;
using System.Configuration;
using System.Data;
using System.Linq;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.HtmlControls;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Xml.Linq;
using Docs.Css;
using Docs.Html;
using System.Collections.Generic;
using System.IO;

namespace HtmlParserOnline
{
    public partial class _Default : System.Web.UI.Page
    {
        protected void Page_Load(object sender, EventArgs e)
        {

        }

        protected void Button1_Click(object sender, EventArgs e)
        {
            TreeView1.Nodes.Clear();

            if (FileUpload1.PostedFile != null && FileUpload1.PostedFile.ContentLength > 0)
            {
                string ext = Path.GetExtension(FileUpload1.PostedFile.FileName);

                switch (ext.ToLower())
                {
                    case ".xhtml":
                    case ".html":
                    case ".htm":
                        HtmlDoc html = HtmlDoc.ParseHTML(FileUpload1.PostedFile.InputStream);
                        BuildHtmlTree(html.Nodes, TreeView1.Nodes);
                        break;
                    case ".css":
                        CssDocument css = CssDocument.ParseCSS(FileUpload1.PostedFile.InputStream);
                        BuildCssTree(css.RuleSets, TreeView1.Nodes);
                        break;
                }
                TreeView1.ExpandAll();
            }
        }

        private void BuildHtmlTree(HtmlNodeCollection nodes, TreeNodeCollection tnodes)
        {
            foreach (HtmlNode node in nodes)
            {
                if (node.IsTag)
                {
                    HtmlTag tag = node as HtmlTag;
                    string tagenc = HtmlEncoder.EncodeValue(tag.ToString());
                    tagenc = tagenc.Replace("\"", "&quot;");

                    TreeNode tnode = new TreeNode(tagenc);
                    tnode.ImageUrl = "images/tag.bmp";
                    tnodes.Add(tnode);

                    BuildHtmlTree(tag.Nodes, tnode.ChildNodes);
                }
                else
                {
                    HtmlText text = node as HtmlText;

                    TreeNode tnode = new TreeNode(text.ToString());
                    tnode.ImageUrl = "images/text.bmp";
                    tnodes.Add(tnode);
                }
            }
        }

        private void BuildCssTree(List<RuleSet> rules, TreeNodeCollection tnodes)
        {
            foreach (RuleSet rule in rules)
            {
                string selst = "";

                // assemble all selectors (simpleselectors)
                for (int i = 0; i < rule.Selectors.Count; i++)
                {
                    if (i > 0) selst += ", ";

                    Selector sel = rule.Selectors[i];
                    selst += sel.ToString();
                }
                TreeNode tnode = new TreeNode("<b>" + selst + "</b>");
                tnode.ImageUrl = "images/tag.bmp";
                tnodes.Add(tnode);


                // show all declarations
                foreach (Declaration decl in rule.Declarations)
                {
                    TreeNode subnode = new TreeNode(decl.ToString());
                    subnode.ImageUrl = "images/text.bmp";
                    tnode.ChildNodes.Add(subnode);
                }
            }
        }
    }
}
